import std/json, std/logging, std/httpclient, std/sequtils, std/strutils
import notion_utils

import ./models, ./service

proc getEventProposalConfig*(cfg: HffEntryFormsApiConfig): EventProposalConfig =
  let http = newNotionClient(
    apiVersion = cfg.notionVersion,
    integrationToken = cfg.integrationToken)

  let apiResp = http.get(cfg.notionApiBaseUrl & "/databases/" & cfg.eventParentId)
  debug apiResp.status

  if not apiResp.status.startsWith("2"):
    debug apiResp.body
    raiseApiError(Http500,
      "unable to read event propsal configuration from notion API")

  let bodyJson = parseJson(apiResp.body)
  let departmentOptionsJson = bodyJson{
    "properties", "Department", "multi_select", "options"}

  if departmentOptionsJson.isNil:
    raiseApiError(Http500,
      "missing read department values from Notion API-supplied event schema")

  return EventProposalConfig(
    departmentOptions: departmentOptionsJson.toSeq.mapIt(
      ( value: it["name"].getStr, color: it["color"].getStr )
    )
  )

proc createProposedEvent*(cfg: HffEntryFormsApiConfig, ep: EventProposal): bool =
  let http = newNotionClient(
    apiVersion = cfg.notionVersion,
    integrationToken = cfg.integrationToken)

  let epNotionPage = ep.asNotionPage
  epNotionPage["parent"] = %*{ "database_id": cfg.eventParentId }

  let apiResp = http.post(cfg.notionApiBaseUrl & "/pages", $epNotionPage)

  debug apiResp.status
  if not apiResp.status.startsWith("2"): debug apiResp.body

  return apiResp.status.startsWith("2")
